# Helper for Maxi

All the Functions I could need multiple times

## Instructions

1. Install:

```
pip install -+-
```

2. Import package:

```python
from helper import *
# You can replace * with what you need!
``` 